clear all;
addpath('mn');
run OCCdefs    % define parameters, Symmetric, etc.
fout = fopen('ex4_ff.dat','w');
Method = Lobatto;
Nmaxout = 10;  % skip large output
Bcolloc = 0;   % 1 for boundary collocation
ch = input( 'Enter g/l/c/r/x for Gauss/Lobatto/Chebyshev/RadauR/RadauL >','s' );
cx = findstr(ch,'glcrx');   if(size(cx,1) > 0)Method = cx; end
ch = input ( 'Enter number interior points first, last, delta >','s' );
ncalc = sscanf(ch,'%i');
zout = [ 0.0001, 0.0002, 0.0005,0.001, 0.002, 0.005, 0.010, 0.02, 0.05, 0.10 ];
nout = length(zout);
for n=ncalc(1):ncalc(3):ncalc(2)
   nt = n + 2;  % total points
   [xc,wc,Ac] = OCnonsym(n,Method);             % .m meth 1:5 = Lobatto, Gauss, Chebyshev, Radau R, Radau L
   [Bc,Cc] = OCBCcoef(wc,Ac,Ac,NonSymmetric);   % .m Laplacian and stiffness
   wx(1:n) = (1.0 - xc(2:n+1).*xc(2:n+1)).*wc(2:n+1);
   D(1:n,1:n) = 0.0;
   if(Bcolloc)
      Cc(nt,:) = Ac(nt,:);    % boundary collocation
   end
   B(1:n,1:n) = Cc(2:n+1,2:n+1) - Cc(2:n+1,nt).*Cc(nt,2:n+1)/Cc(nt,nt);
   D(1:n+1:n*n) = wx(1:n);
   [v,xlm] = eig(B,D);    xl = xlm(1:n+1:n*n);    % eigenvalues and vectors
   [xl,idx] = sort(xl);   v = v(:,idx);           % sort them
   y0(1:n) = ones();  % initial condition
   ck = v\y0';
   yk(1:n+1,1:n) = 0.0;
   yk(1:n,1:n) = v.*ck';
   cm(1:n) = 0.0;
   for k=1:n
      cm(k) = 1.5*wx*yk(1:n,k);                        % coefficients y avg.
      yk(n+1,k) = -(Cc(nt,2:n+1)*yk(1:n,k))/Cc(nt,nt); % coefficients of y
   end
   cd = cm.*xl;  % for derivative calculations
   fprintf(fout,'%s points, n = %i\n',strtrim(strmeth(Method,:)),n)
   if(isreal(xl) == 0)
      disp('**** Complex eigenvalues ****');
      [xmx,imx] = max(imag(xl));
      fprintf(fout,'*** Warning Complex at %i below\n',imx);
   end
   [cmn,imn] = min(cm);
   if(cmn < 0.0)
      fprintf(fout,'*** Warning Negative c at %i below\n',imn);
   end
   ArrayPrintX(fout,cm',xl',(imag(xl))','Coefficients, yavg-c, Eigenvalues(real,imag) :');
   if(n <= Nmaxout)
      ArrayPrint(fout,v,'Eigenvectors');
      ArrayPrint(fout,yk,'yk:');
   end
   fprintf(fout,'%s\n','Calculated Results:');
   fprintf(fout,'%s\t%s\t%s\t%s','       z       ','       sh      ','       ym      ','     dym/dz    ');
   fprintf(fout,'\t%s\t%s\t%s\n','     dy/dx - C ','     dy/dx - A ','      y(:)=>     ');
   y(1:nt) = 0.0;
   for i = 1:nout
      expz = exp(-xl.*zout(i));
      ym = cm*expz';  dym = (cd*expz').*(2.0/3.0);
      sh = dym/(ym);  y(2:nt) = yk(:,:)*expz';
      dydx = -Cc(1,:)*y';
      dydx2 = Ac(1,:)*y';                 % uncorrected
     %dydx2 = dydx2 + wc(1).*Bc(1,:)*y';  % applied correction
      fprintf(fout,'%15.10f\t',zout(i),sh,ym,dym,dydx,dydx2);
      if(n <= Nmaxout)
         for j=1:nt
            fprintf(fout,'%15.8f\t',y(j));
         end
      end
      fprintf(fout,'\n');
   end
end
fclose(fout);


