function [xc,w,A,An] = OCsymGL(n,meth,geom) % symmetric problems
   % n interior points
   % meth = 1,2 for Gauss, Lobatto
   % geom = 0,1,2 for planar, cylindrical, spherical
   % xc - collocation points
   % w  - quadrature weights
   % A  - 1st derivative (even)
   % An - 1st derivative (odd)
   UseEig = 0;    % this controls whether Eigenvalue method used to get roots
   a = meth - 1.0;  b = (geom-1)*0.5;  nt = n + 1;
   if(UseEig == 1)
      ab = r_jacobi(n,a,b);   ab(2:n,2) = sqrt(ab(2:n,2));
      T = diag(ab(2:n,2),-1) + diag(ab(:,1)) + diag(ab(2:n,2),+1);
      x = eig(T);  x=sort(x);
   else
      x = Jacobi_root(n,a,b);    % use iterative method
   end
   x=0.5*(x+1.0); x = [x;1.0];
   xc = sqrt(x);  xdif = x-x'+eye(nt);  dpx = prod(xdif,2); % use eye to avoid divide by 0
   w = ((1.0 .- x).^(2-meth))./(x.*dpx.*dpx);               % quadrature weights
   w = w/((geom+1)*sum(w));                                 % normalize
   A = dpx./(dpx'.*xdif);  A = 2.0*bsxfun(@times,xc,A);     % derivative operator
   A(1:nt+1:nt*nt) = (2.0).*xc - sum(A,2);                  % diagonal for zero row sum
   An = bsxfun(@rdivide,xc,xc').*A;                         % 1st der. of odd function
   An(1:nt+1:nt*nt) = An(1:nt+1:nt*nt) + ((geom+1.0)./xc)'; % diagonal
end

