% test code to do fundamental calculations - all native Matlab/Octave
% basic data for Gauss, Lobatto, Chebyshev, Radau (right and left)
clear all;
addpath('mn');       % location of function files .m and .mex
global fout symm geom meth         % output file handle
run OCCdefs          % script file with useful definitions
symm = NonSymmetric; % default symmetry
meth = Lobatto;      % default point type
geom = Planar;       % default geometry
nout = 21;  xi = [0:1.0/(nout-1.0):1]; % x for interpolation
function [fint,f,df] = Expfunc(x,symm,geom)  % -------------------------
   % f(x) = exp(-5x^2) to test integration, interpolation & differentiation
   run OCCdefs          % script file with useful definitions
   aexp = -5.0;
   f = exp(aexp*(x.*x));    % function values
   df = (2.0*aexp).*x.*f;   % derivative values
   switch geom          % integrals for various geometry
   case Planar       % integral f(x) or f(x^2)
      fint = erf(sqrt(-aexp))*sqrt(-pi/aexp)*(0.5);
   case Cylindrical  % integral f(x^2) x dx
      fint = (-0.5/aexp)*(1.0 - exp(aexp));
   case Spherical    % integral f(x^2) x^2 dx
      fint = (0.25)*sqrt(-pi/aexp**3)*erf(sqrt(-aexp))+(0.5/aexp)*exp(aexp);
   end
end % ------------------------------------------------------------------
disp('Test Orthogonal Collocation Matlab routines');
ch = input( 'Enter Symmetric y/n >','s' );  % get symmetry
if(ch == 'y')symm = Symmetric; end
if(symm == Symmetric)    % geometry, point type
   ch = input( 'Enter planar/cylindrical/spherical = 0/1/2 >','s' );
   geom = str2num(ch);
   ch = input( 'Enter g/l/c for Gauss/Lobatto/Chebyshev >','s' );
   cx = findstr(ch,'glc');   if(size(cx,1) > 0)meth = cx; end
else
   ch = input( 'Enter g/l/c/r/x for Gauss/Lobatto/Chebyshev/RadauR/RadauL >','s' );
   cx = findstr(ch,'glcrx');   if(size(cx,1) > 0)meth = cx; end
end
ch = input( 'Enter number interior points first and last >','s' );   % no. points
ncalc = sscanf(ch,'%i');
ch = input( 'Enter root of output file >','s' );  % output file root
filenm = [ch '.dat'];  fout = fopen(filenm,'w');
fprintf(fout,'%s points, %s problems, %s geometry\n',strtrim(strmeth(meth,:)),
    strtrim(strsymm(symm+1,:)),strtrim(strgeom(geom+1,:)))
for n = ncalc(1):ncalc(2)     % loop over number of interior points
   fprintf(fout,'Results for interior Points = %i\n',n);
   nt = n + 2 - symm;  % total number of points
   nlog = n*log10(n);
   if(symm == Symmetric)   % symmetric problems
      [xc,wc,Ac,ANc] = OCsym(n,meth,geom);   % .m meth 1:3 = Lobatto, Gauss, Chebyshev
      [Bc,Cc] = OCBCcoef(wc,Ac,ANc,symm);    % .m Laplacian and stiffness
      xc2 = xc.*xc;  xi2 = xi.*xi;
      Lc = Lcoef(xi2',xc2);                  % .m routine
   else                    % nonsymmetric problems
      [xc,wc,Ac] = OCnonsym(n,meth);         % .m meth 1:5 = Lobatto, Gauss, Chebyshev, Radau R, Radau L
      [Bc,Cc] = OCBCcoef(wc,Ac,Ac,symm);     % .m Laplacian and stiffness
      Lc = Lcoef(xi',xc);
   end
   q = Lpoly(xc,symm);                       % monomials, flip for polyval
   for i=1:nt
      Lp(:,i) = polyval(fliplr(q(i,:)),xi);  % same as Lc
   end
   Dc = MassMatrix(xc);                      % Mass Matrix /w f(x) = 1
   Df = MassMatrix(xc,@MassFunc,2);          % f(x) = MassFunc is a simple demo function
   Cs = (Ac')*(bsxfun(@times,wc,Ac));        % A'*W*A to compare to C stiffness matrix
   % test integration and interpolation of exp(aexp*x*x) on 0,1
   [fintx,fc,dfc] = Expfunc(xc,symm,geom);   % values at xc
   [fintx,fx,dfx] = Expfunc(xi,symm,geom);   % values at interpolation pts, xi
   finta = wc'*fc;                           % approx. integral using quadrature
   dfa = Ac*fc;                              % approx. derivatives at xc
   fa = Lc*fc;             % interpolated at xi
   % Print the results to file -------------------
   ArrayPrint(fout,xc,'Base Points:');
   ArrayPrint(fout,wc,'Quadrature Weights:');
   ArrayPrint(fout,Ac,'First Derivative:');
   if(symm == Symmetric)
      ArrayPrint(fout,ANc,'First Derivative of odd quantity:');
   end
   ArrayPrint(fout,Bc,'Laplacian:');
   ArrayPrint(fout,Cc,'Stiffness Matrix A - W*B :');
   ArrayPrint(fout,Cc - Cc','Stiffness Asymmetry?');
   ArrayPrint(fout,Cs,'Alternate Stiffness Matrix At*W*A:');
   ArrayPrint(fout,Cc - Cs,'Stiffness Matrix Difference:');
   ArrayPrint(fout,Dc,'Mass Matrix:');
   ArrayPrint(fout,Df,'Mass Matrix, f(x):');
   ArrayPrint(fout,q,'Interpolating Monomials:');
   ArrayPrintX(fout,xi',Lc,0,'Lagrange interpolating polynomials:');
   ArrayPrintX(fout,xi',Lp,0,'Lagrange interpolating polynomials:');
   % output of tests results
   fprintf(fout,'Integration of exp(-5x^2): n, nlog(n),exact,approx,error\n')
   fprintf(fout,'Integration n:\t%2i\t%10.5f\t%14.8f\t%14.8f\t%11.5e\n',
      n,nlog,fintx,finta,abs(1.0-finta/fintx));
   fprintf(fout,'Values of exp(-5*x^2) & derivatives at points:\n');
   for i=1:nt
      fprintf(fout,'%10.6f\t%14.8f\t%14.8f\t%14.8f\t%11.5e\n',
         xc(i),fc(i),dfc(i),dfa(i),abs(dfc(i)-dfa(i)));
   end
   fprintf(fout,'Interpolation of exp(-5*x^2), x, exact, approx, error:\n');
   for i=1:nout
      fprintf(fout,'%8.2f\t%14.8f\t%14.8f\t%11.5e\n',
         xi(i),fx(i),fa(i),abs(1.0-fa(i)/fx(i)));
   end
end
fclose(fout);


